@@ -1,5 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-""" An extensible ASCII table reader and writer.
+"""An extensible ASCII table reader and writer.
 
 core.py:
   Core base classes and functions for reading and writing tables.
@@ -40,7 +40,7 @@ FAST_CLASSES = {}
 
 
 def _check_multidim_table(table, max_ndim):
-    """Check that ``table`` has only columns with ndim <= ``max_ndim``
+    """Check that ``table`` has only columns with ndim <= ``max_ndim``.
 
     Currently ECSV is the only built-in format that supports output of arbitrary
     N-d columns, but HTML supports 2-d.
@@ -72,7 +72,6 @@ class CsvWriter:
 
     Examples
     --------
-
     >>> from astropy.io.ascii.core import CsvWriter
     >>> writer = CsvWriter(delimiter=' ')
     >>> print(writer.writerow(['hello', '', 'world']))
@@ -160,7 +159,7 @@ class CsvWriter:
 
 
 class MaskedConstant(numpy.ma.core.MaskedConstant):
-    """A trivial extension of numpy.ma.masked
+    """A trivial extension of numpy.ma.masked.
 
     We want to be able to put the generic term ``masked`` into a dictionary.
     The constant ``numpy.ma.masked`` is not hashable (see
@@ -306,8 +305,9 @@ class BaseInputter:
     """Encoding used to read the file"""
 
     def get_lines(self, table, newline=None):
-        """
-        Get the lines from the ``table`` input. The input table can be one of:
+        """Get the lines from the ``table`` input.
+
+        The input table can be one of:
 
         * File name
         * String (newline separated) with all header and data lines (must have at least 2 lines)
@@ -369,7 +369,8 @@ class BaseInputter:
         Override this method if something more has to be done to convert raw
         input lines to the table rows.  For example the
         ContinuationLinesInputter derived class accounts for continuation
-        characters if a row is split into lines."""
+        characters if a row is split into lines.
+        """
         return lines
 
 
@@ -456,7 +457,8 @@ class DefaultSplitter(BaseSplitter):
     def process_line(self, line):
         """Remove whitespace at the beginning or end of line.  This is especially useful for
         whitespace-delimited files to prevent spurious columns at the beginning or end.
-        If splitting on whitespace then replace unquoted tabs with space first"""
+        If splitting on whitespace then replace unquoted tabs with space first.
+        """
         if self.delimiter == r"\s":
             line = _replace_tab_with_space(line, self.escapechar, self.quotechar)
         return line.strip() + "\n"
@@ -519,7 +521,7 @@ class DefaultSplitter(BaseSplitter):
 
 
 def _replace_tab_with_space(line, escapechar, quotechar):
-    """Replace tabs with spaces in given string, preserving quoted substrings
+    """Replace tabs with spaces in given string, preserving quoted substrings.
 
     Parameters
     ----------
@@ -552,7 +554,6 @@ def _get_line_index(line_or_func, lines):
     """Return the appropriate line index, depending on ``line_or_func`` which
     can be either a function, a positive or negative int, or None.
     """
-
     if hasattr(line_or_func, "__call__"):
         return line_or_func(lines)
     elif line_or_func:
@@ -567,7 +568,7 @@ def _get_line_index(line_or_func, lines):
 
 class BaseHeader:
     """
-    Base table header reader
+    Base table header reader.
     """
 
     auto_format = "col{}"
@@ -618,7 +619,6 @@ class BaseHeader:
             List of table lines
 
         """
-
         start_line = _get_line_index(self.start_line, self.process_lines(lines))
         if start_line is None:
             # No header line so auto-generate names from n_data_cols
@@ -644,7 +644,7 @@ class BaseHeader:
         self._set_cols_from_names()
 
     def process_lines(self, lines):
-        """Generator to yield non-blank and non-comment lines"""
+        """Generator to yield non-blank and non-comment lines."""
         re_comment = re.compile(self.comment) if self.comment else None
         # Yield non-comment lines
         for line in lines:
@@ -666,7 +666,7 @@ class BaseHeader:
 
     @property
     def colnames(self):
-        """Return the column names of the table"""
+        """Return the column names of the table."""
         return tuple(
             col.name if isinstance(col, Column) else col.info.name for col in self.cols
         )
@@ -721,9 +721,7 @@ class BaseHeader:
             return self.col_type_map[type_map_key.lower()]
         except KeyError:
             raise ValueError(
-                'Unknown data type ""{}"" for column "{}"'.format(
-                    col.raw_type, col.name
-                )
+                f'Unknown data type ""{col.raw_type}"" for column "{col.name}"'
             )
 
     def check_column_names(self, names, strict_names, guessing):
@@ -807,7 +805,7 @@ class BaseData:
 
     def process_lines(self, lines):
         """
-        READ: Strip out comment lines and blank lines from list of ``lines``
+        READ: Strip out comment lines and blank lines from list of ``lines``.
 
         Parameters
         ----------
@@ -842,11 +840,12 @@ class BaseData:
 
     def get_str_vals(self):
         """Return a generator that returns a list of column values (as strings)
-        for each data line."""
+        for each data line.
+        """
         return self.splitter(self.data_lines)
 
     def masks(self, cols):
-        """READ: Set fill value for each column and then apply that fill value
+        """READ: Set fill value for each column and then apply that fill value.
 
         In the first step it is evaluated with value from ``fill_values`` applies to
         which column using ``fill_include_names`` and ``fill_exclude_names``.
@@ -857,7 +856,7 @@ class BaseData:
             self._set_masks(cols)
 
     def _set_fill_values(self, cols):
-        """READ, WRITE: Set fill values of individual cols based on fill_values of BaseData
+        """READ, WRITE: Set fill values of individual cols based on fill_values of BaseData.
 
         fill values has the following form:
         <fill_spec> = (<bad_value>, <fill_value>, <optional col_name>...)
@@ -906,7 +905,7 @@ class BaseData:
                     cols[i].fill_values[replacement[0]] = str(replacement[1])
 
     def _set_masks(self, cols):
-        """READ: Replace string values in col.str_vals and set masks"""
+        """READ: Replace string values in col.str_vals and set masks."""
         if self.fill_values:
             for col in (col for col in cols if col.fill_values):
                 col.mask = numpy.zeros(len(col.str_vals), dtype=bool)
@@ -917,7 +916,7 @@ class BaseData:
                     col.mask[i] = True
 
     def _replace_vals(self, cols):
-        """WRITE: replace string values in col.str_vals"""
+        """WRITE: replace string values in col.str_vals."""
         if self.fill_values:
             for col in (col for col in cols if col.fill_values):
                 for i, str_val in (
@@ -930,7 +929,7 @@ class BaseData:
                         col.str_vals[i] = mask_val
 
     def str_vals(self):
-        """WRITE: convert all values in table to a list of lists of strings
+        """WRITE: convert all values in table to a list of lists of strings.
 
         This sets the fill values and possibly column formats from the input
         formats={} keyword, then ends up calling table.pprint._pformat_col_iter()
@@ -1002,7 +1001,6 @@ def convert_numpy(numpy_type):
         Raised by ``converter`` if the list elements could not be converted to
         the required type.
     """
-
     # Infer converter type from an instance of numpy_type.
     type_name = numpy.array([], dtype=numpy_type).dtype.name
     if "int" in type_name:
@@ -1063,7 +1061,8 @@ class BaseOutputter:
     def _validate_and_copy(col, converters):
         """Validate the format for the type converters and then copy those
         which are valid converters for this column (i.e. converter type is
-        a subclass of col.type)"""
+        a subclass of col.type).
+        """
         # Allow specifying a single converter instead of a list of converters.
         # The input `converters` must be a ``type`` value that can init np.dtype.
         try:
@@ -1150,7 +1149,7 @@ class BaseOutputter:
 
 
 def _deduplicate_names(names):
-    """Ensure there are no duplicates in ``names``
+    """Ensure there are no duplicates in ``names``.
 
     This is done by iteratively adding ``_<N>`` to the name for increasing N
     until the name is unique.
@@ -1496,7 +1495,7 @@ class BaseReader(metaclass=MetaBaseReader):
 
     @property
     def comment_lines(self):
-        """Return lines in the table that match header.comment regexp"""
+        """Return lines in the table that match header.comment regexp."""
         if not hasattr(self, "lines"):
             raise ValueError(
                 "Table must be read prior to accessing the header comment lines"
@@ -1547,7 +1546,6 @@ class BaseReader(metaclass=MetaBaseReader):
             List of strings corresponding to ASCII table
 
         """
-
         # Check column names before altering
         self.header.cols = list(table.columns.values())
         self.header.check_column_names(self.names, self.strict_names, False)
@@ -1584,8 +1582,9 @@ class BaseReader(metaclass=MetaBaseReader):
 
 
 class ContinuationLinesInputter(BaseInputter):
-    """Inputter where lines ending in ``continuation_char`` are joined
-    with the subsequent line.  Example::
+    """Inputter where lines ending in ``continuation_char`` are joined with the subsequent line.
+
+    Example::
 
       col1 col2 col3
       1 \
@@ -1621,7 +1620,7 @@ class ContinuationLinesInputter(BaseInputter):
 
 class WhitespaceSplitter(DefaultSplitter):
     def process_line(self, line):
-        """Replace tab with space within ``line`` while respecting quoted substrings"""
+        """Replace tab with space within ``line`` while respecting quoted substrings."""
         newline = []
         in_quote = False
         lastchar = None
@@ -1667,7 +1666,6 @@ def _get_reader(Reader, Inputter=None, Outputter=None, **kwargs):
     for param docs.  This routine is for internal (package) use only and is useful
     because it depends only on the "core" module.
     """
-
     from .fastbasic import FastBasic
 
     if issubclass(Reader, FastBasic):  # Fast readers handle args separately
@@ -1793,8 +1791,8 @@ extra_writer_pars = (
 def _get_writer(Writer, fast_writer, **kwargs):
     """Initialize a table writer allowing for common customizations. This
     routine is for internal (package) use only and is useful because it depends
-    only on the "core" module."""
-
+    only on the "core" module.
+    """
     from .fastbasic import FastBasic
 
     # A value of None for fill_values imply getting the default string
