@@ -4,16 +4,23 @@ import math
 import os
 import re
 import time
+from io import BytesIO
+from itertools import product
 
 import numpy as np
 import pytest
+from hypothesis import given
+from hypothesis.extra.numpy import basic_indices
 from numpy.testing import assert_equal
 
 from astropy.io import fits
-from astropy.io.fits.hdu.compressed import DITHER_SEED_CHECKSUM, SUBTRACTIVE_DITHER_1
-from astropy.utils.compat.optional_deps import HAS_SCIPY
-from astropy.utils.data import get_pkg_data_filename
-from astropy.utils.exceptions import AstropyUserWarning
+from astropy.io.fits.hdu.compressed import (
+    COMPRESSION_TYPES,
+    DITHER_SEED_CHECKSUM,
+    SUBTRACTIVE_DITHER_1,
+)
+from astropy.utils.data import download_file, get_pkg_data_filename
+from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyUserWarning
 
 from .conftest import FitsTestCase
 from .test_table import comparerecords
@@ -303,7 +310,6 @@ class TestImageFunctions(FitsTestCase):
             os.rename(self.temp("test_new.fits"), self.temp("test_append.fits"))
 
             with fits.open(self.temp("test_append.fits"), mode="append") as a:
-
                 # The above change did not take effect since this was made
                 # after the flush().
                 assert a[1].data[1, 1] == 349
@@ -316,7 +322,6 @@ class TestImageFunctions(FitsTestCase):
             os.rename(self.temp("test_append.fits"), self.temp("test_update.fits"))
 
             with fits.open(self.temp("test_update.fits"), mode="update") as u:
-
                 # When the changes do not alter the size structures of the
                 # original (or since last flush) HDUList, the changes are
                 # written back "in place".
@@ -1043,7 +1048,7 @@ class TestImageFunctions(FitsTestCase):
         hdu.header["BLANK"] = "nan"
         with pytest.warns(
             fits.verify.VerifyWarning,
-            match=r"Invalid value for " r"'BLANK' keyword in header: 'nan'",
+            match=r"Invalid value for 'BLANK' keyword in header: 'nan'",
         ):
             hdu.writeto(self.temp("test.fits"))
 
@@ -1121,6 +1126,11 @@ class TestImageFunctions(FitsTestCase):
             fits.ImageHDU(data=1)
         with pytest.raises(TypeError, match=msg):
             fits.PrimaryHDU(data=1)
+        # Regression test for https://github.com/astropy/astropy/issues/14527
+        with pytest.raises(TypeError, match=msg):
+            fits.ImageHDU(data=np.array(1))
+        with pytest.raises(TypeError, match=msg):
+            fits.PrimaryHDU(data=np.array(1))
 
 
 class TestCompressedImage(FitsTestCase):
@@ -1178,7 +1188,6 @@ class TestCompressedImage(FitsTestCase):
             assert fd[1].header["NAXIS2"] == chdu.header["NAXIS2"]
             assert fd[1].header["BITPIX"] == chdu.header["BITPIX"]
 
-    @pytest.mark.skipif(not HAS_SCIPY, reason="requires scipy")
     @pytest.mark.remote_data
     def test_comp_image_quantize_level(self):
         """
@@ -1187,19 +1196,16 @@ class TestCompressedImage(FitsTestCase):
         Test that quantize_level is used.
 
         """
-        import scipy
+        import pickle
 
-        from astropy.utils import minversion
-
-        SCIPY_LT_1_10 = not minversion(scipy, "1.10dev0")
         np.random.seed(42)
 
-        if SCIPY_LT_1_10:
-            import scipy.misc  # No lazy loading for SCIPY_LT_1_9
-
-            scipy_data = scipy.misc.ascent()
-        else:
-            scipy_data = scipy.datasets.ascent()
+        # Basically what scipy.datasets.ascent() does.
+        fname = download_file(
+            "https://github.com/scipy/dataset-ascent/blob/main/ascent.dat?raw=true"
+        )
+        with open(fname, "rb") as f:
+            scipy_data = np.array(pickle.load(f))
 
         data = scipy_data + np.random.randn(512, 512) * 10
 
@@ -1242,7 +1248,7 @@ class TestCompressedImage(FitsTestCase):
             name="SCI",
             compression_type="HCOMPRESS_1",
             quantize_level=16,
-            tile_size=[2, 10, 10],
+            tile_shape=(2, 10, 10),
         )
 
     def test_comp_image_hcompress_image_stack(self):
@@ -1260,7 +1266,7 @@ class TestCompressedImage(FitsTestCase):
             name="SCI",
             compression_type="HCOMPRESS_1",
             quantize_level=16,
-            tile_size=[5, 5, 1],
+            tile_shape=(1, 5, 5),
         )
         hdu.writeto(self.temp("test.fits"))
 
@@ -1510,7 +1516,7 @@ class TestCompressedImage(FitsTestCase):
         np.random.seed(1337)
         data1 = np.random.uniform(size=(6 * 4, 7 * 4))
         data1[: data2.shape[0], : data2.shape[1]] = data2
-        chdu = fits.CompImageHDU(data1, compression_type="RICE_1", tile_size=(6, 7))
+        chdu = fits.CompImageHDU(data1, compression_type="RICE_1", tile_shape=(6, 7))
         chdu.writeto(self.temp("test.fits"))
 
         with fits.open(self.temp("test.fits"), disable_image_compression=True) as h:
@@ -1932,14 +1938,23 @@ class TestCompressedImage(FitsTestCase):
         new = fits.getdata(testfile)
         np.testing.assert_array_equal(data, new)
 
-    def test_write_non_contiguous_data(self):
+    @pytest.mark.parametrize(
+        ("dtype", "compression_type"), product(("f", "i4"), COMPRESSION_TYPES)
+    )
+    def test_write_non_contiguous_data(self, dtype, compression_type):
         """
         Regression test for https://github.com/astropy/astropy/issues/2150
+
+        This used to require changing the whole array to be C-contiguous before
+        passing to CFITSIO, but we no longer need this - our explicit conversion
+        to bytes in the compression codecs returns contiguous bytes for each
+        tile on-the-fly.
         """
-        orig = np.arange(100, dtype=float).reshape((10, 10), order="f")
+
+        orig = np.arange(400, dtype=dtype).reshape((20, 20), order="f")[::2, ::2]
         assert not orig.flags.contiguous
         primary = fits.PrimaryHDU()
-        hdu = fits.CompImageHDU(orig)
+        hdu = fits.CompImageHDU(orig, compression_type=compression_type)
         hdulist = fits.HDUList([primary, hdu])
         hdulist.writeto(self.temp("test.fits"))
 
@@ -1959,6 +1974,99 @@ class TestCompressedImage(FitsTestCase):
             with fits.open(self.temp("test.fits")) as hdul2:
                 assert_equal(hdul1[1].data[:200, :100], hdul2[1].data)
 
+    def test_comp_image_deprecated_tile_size(self):
+        # Ensure that tile_size works but is deprecated. This test
+        # can be removed once support for tile_size is removed.
+
+        with pytest.warns(
+            AstropyDeprecationWarning,
+            match="The tile_size argument has been deprecated",
+        ):
+            chdu = fits.CompImageHDU(np.zeros((3, 4, 5)), tile_size=(5, 2, 1))
+
+        assert chdu.tile_shape == (1, 2, 5)
+
+    def test_comp_image_deprecated_tile_size_and_tile_shape(self):
+        # Make sure that tile_size and tile_shape are not both specified
+
+        with pytest.warns(AstropyDeprecationWarning) as w:
+            with pytest.raises(
+                ValueError, match="Cannot specify both tile_size and tile_shape."
+            ):
+                fits.CompImageHDU(
+                    np.zeros((3, 4, 5)), tile_size=(5, 2, 1), tile_shape=(3, 2, 3)
+                )
+
+    def test_comp_image_properties_default(self):
+        chdu = fits.CompImageHDU(np.zeros((3, 4, 5)))
+        assert chdu.tile_shape == (1, 1, 5)
+        assert chdu.compression_type == "RICE_1"
+
+    def test_comp_image_properties_set(self):
+        chdu = fits.CompImageHDU(
+            np.zeros((3, 4, 5)), compression_type="PLIO_1", tile_shape=(2, 3, 4)
+        )
+        assert chdu.tile_shape == (2, 3, 4)
+        assert chdu.compression_type == "PLIO_1"
+
+
+class TestCompHDUSections:
+    @pytest.fixture(autouse=True)
+    def setup_method(self, tmp_path):
+        shape = (13, 17, 25)
+        self.data = np.arange(np.prod(shape)).reshape(shape).astype(np.int32)
+
+        header1 = fits.Header()
+        hdu1 = fits.CompImageHDU(
+            self.data, header1, compression_type="RICE_1", tile_shape=(5, 4, 5)
+        )
+
+        header2 = fits.Header()
+        header2["BSCALE"] = 2
+        header2["BZERO"] = 100
+        hdu2 = fits.CompImageHDU(
+            self.data, header2, compression_type="RICE_1", tile_shape=(5, 4, 5)
+        )
+        hdulist = fits.HDUList([fits.PrimaryHDU(), hdu1, hdu2])
+        hdulist.writeto(tmp_path / "sections.fits")
+
+        self.hdul = fits.open(tmp_path / "sections.fits")
+
+    def teardown_method(self):
+        self.hdul.close()
+        self.hdul = None
+
+    @given(basic_indices((13, 17, 25)))
+    def test_section_slicing(self, index):
+        assert_equal(self.hdul[1].section[index], self.hdul[1].data[index])
+        assert_equal(self.hdul[1].section[index], self.data[index])
+
+    @given(basic_indices((13, 17, 25)))
+    def test_section_slicing_scaling(self, index):
+        assert_equal(self.hdul[2].section[index], self.hdul[2].data[index])
+        assert_equal(self.hdul[2].section[index], self.data[index] * 2 + 100)
+
+
+def test_comphdu_fileobj():
+    # Regression test for a bug that caused an error to happen
+    # internally when reading the data if requested data shapes
+    # were not plain integers - this was triggered when accessing
+    # sections on data backed by certain kinds of objects such as
+    # BytesIO (but not regular file handles)
+
+    data = np.arange(6).reshape((2, 3)).astype(np.int32)
+
+    byte_buffer = BytesIO()
+
+    header = fits.Header()
+    hdu = fits.CompImageHDU(data, header, compression_type="RICE_1")
+    hdu.writeto(byte_buffer)
+
+    byte_buffer.seek(0)
+
+    hdu2 = fits.open(byte_buffer, mode="readonly")[1]
+    assert hdu2.section[1, 2] == 5
+
 
 def test_comphdu_bscale(tmp_path):
     """
@@ -1993,7 +2101,6 @@ def test_comphdu_bscale(tmp_path):
 
 
 def test_scale_implicit_casting():
-
     # Regression test for an issue that occurred because Numpy now does not
     # allow implicit type casting during inplace operations.
 
@@ -2002,7 +2109,6 @@ def test_scale_implicit_casting():
 
 
 def test_bzero_implicit_casting_compressed():
-
     # Regression test for an issue that occurred because Numpy now does not
     # allow implicit type casting during inplace operations. Astropy is
     # actually not able to produce a file that triggers the failure - the
@@ -2031,7 +2137,6 @@ def test_bzero_mishandled_info(tmp_path):
 
 
 def test_image_write_readonly(tmp_path):
-
     # Regression test to make sure that we can write out read-only arrays (#5512)
 
     x = np.array([1, 2, 3])
