@@ -43,6 +43,13 @@ ALL_DTYPES = [
     "U3",
 ]
 
+BIGENDIAN_DTYPES = [
+    np.dtype(">i4"),
+    np.dtype(">i8"),
+    np.dtype(">f4"),
+    np.dtype(">f8"),
+]
+
 
 def _default_values(dtype):
     if dtype == np.bool_:
@@ -55,6 +62,29 @@ def _default_values(dtype):
         return [1, 2, 3]
 
 
+def _default_array_values(dtype):
+    values = _default_values(dtype)
+    return [values for i in range(3)]
+
+
+def _default_var_length_array_values(dtype):
+    values = _default_values(dtype)
+    return [
+        [
+            values[0],
+        ],
+        [
+            values[0],
+            values[1],
+        ],
+        [
+            values[0],
+            values[1],
+            values[2],
+        ],
+    ]
+
+
 def test_read_write_simple(tmp_path):
     """Test writing/reading a simple parquet file."""
     test_file = tmp_path / "test.parquet"
@@ -195,6 +225,109 @@ def test_preserve_single_dtypes(tmp_path, dtype):
     assert t2["a"].dtype == dtype
 
 
+@pytest.mark.parametrize("dtype", BIGENDIAN_DTYPES)
+def test_preserve_single_bigendian_dtypes(tmp_path, dtype):
+    """Test that round-tripping a single big-endian column preserves data."""
+
+    test_file = tmp_path / "test.parquet"
+
+    values = _default_values(dtype)
+
+    t1 = Table()
+    t1.add_column(Column(name="a", data=np.array(values, dtype=dtype)))
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    assert np.all(t2["a"] == values)
+    # The parquet serialization will turn all arrays into little-endian.
+    assert t2["a"].dtype == dtype.newbyteorder("<")
+
+
+@pytest.mark.parametrize("dtype", ALL_DTYPES)
+def test_preserve_single_array_dtypes(tmp_path, dtype):
+    """Test that round-tripping a single array column preserves datatypes."""
+
+    test_file = tmp_path / "test.parquet"
+
+    values = _default_array_values(dtype)
+
+    t1 = Table()
+    t1.add_column(Column(name="a", data=np.array(values, dtype=dtype)))
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    assert np.all(t2["a"] == t1["a"])
+    assert np.all(t2["a"].shape == np.array(values).shape)
+    assert t2["a"].dtype == dtype
+
+
+@pytest.mark.parametrize("dtype", BIGENDIAN_DTYPES)
+def test_preserve_single_bigendian_array_dtypes(tmp_path, dtype):
+    """Test that round-tripping a single array column (big-endian) preserves data."""
+
+    test_file = tmp_path / "test.parquet"
+
+    values = _default_array_values(dtype)
+
+    t1 = Table()
+    t1.add_column(Column(name="a", data=np.array(values, dtype=dtype)))
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    assert np.all(t2["a"] == t1["a"])
+    assert np.all(t2["a"].shape == np.array(values).shape)
+    assert t2["a"].dtype == dtype.newbyteorder("<")
+
+
+@pytest.mark.parametrize("dtype", ALL_DTYPES)
+def test_preserve_single_var_length_array_dtypes(tmp_path, dtype):
+    """
+    Test that round-tripping a single variable length array column preserves
+    datatypes.
+    """
+
+    test_file = tmp_path / "test.parquet"
+
+    values = _default_var_length_array_values(dtype)
+
+    t1 = Table()
+    data = np.array([np.array(val, dtype=dtype) for val in values], dtype=np.object_)
+    t1.add_column(Column(name="a", data=data))
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    for row1, row2 in zip(t1["a"], t2["a"]):
+        assert np.all(row1 == row2)
+        assert row1.dtype == row2.dtype
+
+
+@pytest.mark.parametrize("dtype", BIGENDIAN_DTYPES)
+def test_preserve_single_bigendian_var_length_array_dtypes(tmp_path, dtype):
+    """
+    Test that round-tripping a single big-endian variable length array column preserves
+    datatypes.
+    """
+
+    test_file = tmp_path / "test.parquet"
+
+    values = _default_var_length_array_values(dtype)
+
+    t1 = Table()
+    data = np.array([np.array(val, dtype=dtype) for val in values], dtype=np.object_)
+    t1.add_column(Column(name="a", data=data))
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    for row1, row2 in zip(t1["a"], t2["a"]):
+        assert np.all(row1 == row2)
+        assert row1.dtype.newbyteorder(">") == row2.dtype.newbyteorder(">")
+
+
 def test_preserve_all_dtypes(tmp_path):
     """Test that round-tripping preserves a table with all the datatypes."""
 
@@ -206,6 +339,11 @@ def test_preserve_all_dtypes(tmp_path):
         values = _default_values(dtype)
         t1.add_column(Column(name=str(dtype), data=np.array(values, dtype=dtype)))
 
+        arr_values = _default_array_values(dtype)
+        t1.add_column(
+            Column(name=str(dtype) + "_arr", data=np.array(arr_values, dtype=dtype))
+        )
+
     t1.write(test_file)
 
     t2 = Table.read(test_file)
@@ -215,6 +353,107 @@ def test_preserve_all_dtypes(tmp_path):
         assert np.all(t2[str(dtype)] == values)
         assert t2[str(dtype)].dtype == dtype
 
+        arr_values = _default_array_values(dtype)
+        assert np.all(t2[str(dtype) + "_arr"] == values)
+        assert t2[str(dtype)].dtype == dtype
+        assert np.all(t2[str(dtype) + "_arr"].shape == np.array(arr_values).shape)
+
+    # Test just reading the schema
+    schema2 = Table.read(test_file, schema_only=True)
+    assert len(schema2) == 0
+    assert schema2.dtype == t2.dtype
+
+
+def test_preserve_all_var_length_dtypes(tmp_path):
+    """Test that round-tripping preserves a table with all the var length datatypes."""
+
+    test_file = tmp_path / "test.parquet"
+
+    t1 = Table()
+
+    for dtype in ALL_DTYPES:
+        varr_values = _default_var_length_array_values(dtype)
+        data = np.array(
+            [np.array(val, dtype=dtype) for val in varr_values], dtype=np.object_
+        )
+        t1.add_column(Column(name=str(dtype) + "_varr", data=data))
+
+    t1.write(test_file)
+
+    t2 = Table.read(test_file)
+
+    for dtype in ALL_DTYPES:
+        varr_values = _default_var_length_array_values(dtype)
+        colname = str(dtype) + "_varr"
+        for row1, row2 in zip(t1[colname], t2[colname]):
+            assert np.all(row1 == row2)
+            assert row1.dtype == row2.dtype
+
+
+def test_write_empty_tables(tmp_path):
+    """Test that we can save an empty table with var length datatypes."""
+
+    test_file = tmp_path / "test.parquet"
+
+    t1 = Table()
+
+    for dtype in ALL_DTYPES:
+        values = _default_values(dtype)
+        t1.add_column(Column(name=str(dtype), data=np.array(values, dtype=dtype)))
+
+        arr_values = _default_array_values(dtype)
+        t1.add_column(
+            Column(name=str(dtype) + "_arr", data=np.array(arr_values, dtype=dtype))
+        )
+
+    # Write an empty table with values and arrays, and confirm it works.
+    data = np.zeros(0, dtype=t1.dtype)
+    t2 = Table(data=data)
+
+    t2.write(test_file)
+
+    t3 = Table.read(test_file)
+
+    assert t3.dtype == t2.dtype
+
+    test_file2 = tmp_path / "test2.parquet"
+
+    t4 = Table()
+    for dtype in ALL_DTYPES:
+        varr_values = _default_var_length_array_values(dtype)
+        data = np.array(
+            [np.array(val, dtype=dtype) for val in varr_values], dtype=np.object_
+        )
+        t4.add_column(Column(name=str(dtype) + "_varr", data=data))
+
+    # Write an empty table with variable-length arrays, and confirm this
+    # raises an exception. (The datatype of an np.object_ type column
+    # cannot be inferred from an empty table.)
+    data = np.zeros(0, dtype=t4.dtype)
+    t5 = Table(data=data)
+    with pytest.raises(ValueError, match="Cannot serialize zero-length table") as err:
+        t5.write(test_file2)
+
+
+def test_heterogeneous_var_array_table(tmp_path):
+    """Test exception when trying to serialize a mixed-type variable-length column."""
+
+    test_file = tmp_path / "test.parquet"
+
+    t1 = Table()
+
+    data = np.array(
+        [
+            np.array([0, 1, 2], dtype=np.int32),
+            np.array([0, 1, 2, 3, 4], dtype=np.float64),
+        ],
+        dtype=np.object_,
+    )
+    t1.add_column(Column(name="a", data=data))
+
+    with pytest.raises(ValueError, match="Cannot serialize mixed-type column") as err:
+        t1.write(test_file)
+
 
 def test_preserve_meta(tmp_path):
     """Test that writing/reading preserves metadata."""
